@@ -27,6 +27,7 @@ class Course(models.Model):
     lastupdated_date = models.DateTimeField('date updated',default=datetime.datetime.now)
     version = models.BigIntegerField()
     title = models.TextField(blank=False)
+    description = models.TextField(blank=True, null=True, default=None)
     shortname = models.CharField(max_length=20)
     filename = models.CharField(max_length=200)
     badge_icon = models.FileField(upload_to="badges",blank=True, default=None)
@@ -115,6 +116,10 @@ class Tag(models.Model):
     created_date = models.DateTimeField('date created',default=datetime.datetime.now)
     created_by = models.ForeignKey(User)
     courses = models.ManyToManyField(Course, through='CourseTag')
+    description = models.TextField(blank=True, null=True, default=None)
+    order_priority = models.IntegerField(default=0)
+    highlight = models.BooleanField(default=False)
+    icon = models.FileField(upload_to="tags", null=True, blank=True, default=None) 
     
     class Meta:
         verbose_name = _('Tag')
